==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Complete/Gui/Resources/translations/Complete_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Tam</translation>
    </message>
    <message>
      <source>Constraint Axle...</source>
      <translation>Sınırlama Mili...</translation>
    </message>
    <message>
      <source>set a axle constraint between two objects</source>
      <translation>İki nesne arasındaki sınırlama milini belirle</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Otomatik test</translation>
    </message>
    <message>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Uygulamanın düzgün çalışıp çalışmadığını denetlemek için bir sınama çalıştırır</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Dr&amp;awing</source>
      <translation>Çi&amp;zim</translation>
    </message>
    <message>
      <source>S&amp;ketch</source>
      <translation>&amp;Kroki</translation>
    </message>
    <message>
      <source>&amp;Raytracing</source>
      <translation>&amp;Işınizleme</translation>
    </message>
    <message>
      <source>&amp;Drafting</source>
      <translation>&amp;Çiziliyor</translation>
    </message>
    <message>
      <source>Sketch based</source>
      <translation>Kroki temelli</translation>
    </message>
    <message>
      <source>Primitives</source>
      <translation>Temel öğeler</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation>Değişken tabanlı (Parametrik)</translation>
    </message>
    <message>
      <source>Object appearence</source>
      <translation>Nesne görünümü</translation>
    </message>
    <message>
      <source>Wire Tools</source>
      <translation>Tel Araçları</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Complete/Gui/Resources/translations/Complete_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>CmdCompleteConstraintAxle</name>
    <message>
      <location filename="../../Command.cpp" line="+42"/>
      <source>Complete</source>
      <translation>Tam</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Constraint Axle...</source>
      <translation>Sınırlama Mili...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>set a axle constraint between two objects</source>
      <translation>İki nesne arasındaki sınırlama milini belirle</translation>
    </message>
  </context>
  <context>
    <name>Test_Test</name>
    <message>
      <location filename="../../Workbench.cpp" line="+57"/>
      <source>Self-test...</source>
      <translation>Otomatik test</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Runs a self-test to check if the application works properly</source>
      <translation>Uygulamanın düzgün çalışıp çalışmadığını denetlemek için bir sınama çalıştırır</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location line="-9"/>
      <source>Dr&amp;awing</source>
      <translation>Çi&amp;zim</translation>
    </message>
    <message>
      <location line="-1"/>
      <source>S&amp;ketch</source>
      <translation>&amp;Kroki</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>&amp;Raytracing</source>
      <translation>&amp;Işınizleme</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Drafting</source>
      <translation>&amp;Çiziliyor</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Sketch based</source>
      <translation>Kroki temelli</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Primitives</source>
      <translation>Temel öğeler</translation>
    </message>
    <message>
      <source>Parametric</source>
      <translation type="obsolete">Değişken tabanlı (Parametrik)</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Object appearence</source>
      <translation>Nesne görünümü</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Wire Tools</source>
      <translation>Tel Araçları</translation>
    </message>
  </context>
</TS>
